import os


class FlaskDevelopmentConfig:
    ENV_NAME = 'dev'
    SQLALCHEMY_DATABASE_URI = 'sqlite://'

class FlaskTestingConfig:
    ENV_NAME = 'test'
    SQLALCHEMY_DATABASE_URI = 'sqlite://'

def get_config_by_env(env):

    envs = [
        FlaskTestingConfig,
        FlaskDevelopmentConfig,
        ]

    envs_dict = {e.ENV_NAME: e for e in envs}

    return envs_dict[env]



import os
from .factory import FlaskFactory
#from .views import obx
from .models import db


def get_aws_keys():
    import hvac
    client = hvac.Client(
                url=os.environ.get('VAULT_ADDR', 'http://localhost:8200'),
                token=os.environ.get('VAULT_TOKEN', 'null'),
                )
    creds = client.read('aws/creds/{}'.format(os.environ.get('VAULT_ROLE', 'default')))
    creds.update({'aws_region': 'us-east-1'})
    return {k: v for k, v in creds['data'].items() if 'key' in k}


def get_app():
    factory = FlaskFactory()
    
#     blueprint_dicts = [
#             dict(
#                 bp=obx,
#             )
#         ]
    
    app = factory.initiallize_flask(db)  # , blueprint_dicts)
    app.config.update(get_aws_keys())
    return app



from flask import Flask
from flask_sqlalchemy import SQLAlchemy

from .config import get_config_by_env


class FlaskFactory:

    def __init__(self, env='dev'):
        self.config = get_config_by_env(env)

    def initiallize_flask(self, db):  # , blueprint_dicts)
        app = Flask(__name__)
        app.config.from_object(self.config)
        with app.app_context() as ctx:
            ctx.push()
            db.init_app(app)
#        for blueprint_dict in blueprint_dicts:
#            bp = blueprint_dict.pop('bp')
#            app.register_blueprint(bp, **blueprint_dict)
        return app

    @staticmethod
    def create_db():
        db = SQLAlchemy()
        return db



from .factory import FlaskFactory

db = FlaskFactory.create_db()


class MessageModel(db.Model):

    id = db.Column(db.Integer, primary_key=True)
    message_body = db.Column(db.String(420))
    hash = db.Column(db.String(80))



# -*- coding: utf-8 -*-

import os

from .app import get_app


"""Top-level package for Tengu."""

__author__ = """Barak Avrahami"""
__email__ = 'barak1345@gmail.com'
__version__ = '0.1.12'

app = get_app()



import json
import socket
from flask import Blueprint, request
import boto3
from .__init__ import app



#obx = Blueprint('obx', __name__)

def page_view_log_count():
    client = boto3.client(
            'cloudwatch',
            aws_access_key_id=app.config['access_key'],
            aws_secret_access_key=app.config['secret_key'],
            aws_region=app.config['aws_region'],
            )

    response = client.put_metric_data(
        Namespace='Application',
        MetricData=[
            {
                'MetricName': 'ViewCount',
                'Value': 1.0,
                'Unit': 'Count',
            },
        ]
    )

    return response


@app.route('/')
def root_view():
    page_view_log_count()
    return 'Hello World ' + socket.gethostname()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages
import tengu

version = tengu.__version__

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
        'flask-sqlalchemy',
        'flask',
        'schedule',
        'hvac',
    ]

setup_requirements = []

test_requirements = [
        'tox',
    ]

setup(
    author="Barak Avrahami",
    author_email='barak1345@gmail.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    description="Tengu is an OpenBalkans node implementation",
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='tengu',
    name='tengu',
    packages=find_packages(include=['tengu']),
    python_requires='>=3',
    setup_requires=setup_requirements,
    test_suite='tests',
    entry_points={
        'console_scripts': [
            'tengu=tengu.cli:main_entrypoint'
            ]
        },
    tests_require=test_requirements,
    url='https://github.com/andecy64/tengu',
    version=version,
    zip_safe=False,
)



import argparse
from .app import get_app

def main(port, init_db=False):

    app = get_app()

    if init_db:
        from .models import db
        db.create_all()

    app.run(port=port, host='0.0.0.0')


def main_entrypoint():
    parser = argparse.ArgumentParser()
    parser.add_argument('-p', action='store', help='Port',
                        default=5000, type=int, dest='port')
    parser.add_argument('--init-db', action='store_true', help='create db',
                        dest='init_db')
    args = parser.parse_args()

    main(port=args.port, init_db=args.init_db)
